"""Top-level package for NASA Ocean Color."""

import os
import sys
import warnings

from .storage import OceanColorDB

__author__ = """Guilherme Castelão"""
__email__ = "guilherme@castelao.net"

from pkg_resources import get_distribution, DistributionNotFound

try:
    __version__ = get_distribution(__name__).version
except DistributionNotFound:
    try:
        from .version import version as __version__
    except ImportError:
        raise ImportError(
            "Failed to find (autogenerated) version.py. "
            "This might be because you are installing from GitHub's tarballs, "
            "use the PyPI ones."
        )

# Recent OSX requires this environment variable to run parallel processes
if sys.platform == "darwin":
    if os.environ.get("OBJC_DISABLE_INITIALIZE_FORK_SAFETY") != "YES":
        msg = "You might require OBJC_DISABLE_INITIALIZE_FORK_SAFETY=YES"
        warnings.warn(msg, RuntimeWarning)

__all__ = ("backend",)
